Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(415)

Unified Diff: ios/web/navigation/crw_session_controller.mm

Issue 2766453002: Implement Reload for ORIGINAL_REQUEST_URL in NavigationManagerImpl. (Closed)
Patch Set: Addressed comments Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: ios/web/navigation/crw_session_controller.mm
diff --git a/ios/web/navigation/crw_session_controller.mm b/ios/web/navigation/crw_session_controller.mm
index ec96f47dcabb4f70455b788b5610428df4e61e56..0f2a413a176b69d03a2161e60dc03e5beb93a97b 100644
--- a/ios/web/navigation/crw_session_controller.mm
+++ b/ios/web/navigation/crw_session_controller.mm
@@ -369,7 +369,7 @@ - (void)clearForwardItems {
if (_previousItemIndex >= forwardItemStartIndex)
_previousItemIndex = -1;
// Remove the NavigationItems and notify the NavigationManater
_items.erase(_items.begin() + forwardItemStartIndex, _items.end());
if (_navigationManager) {
_navigationManager->OnNavigationItemsPruned(itemCount -
@@ -544,6 +544,10 @@ - (void)removeItemAtIndex:(NSInteger)index {
_lastCommittedItemIndex--;
if (_previousItemIndex >= index)
_previousItemIndex--;
+
liaoyuke 2017/03/27 16:22:43 I see the following code in clearForwardItems: if
Eugene But (OOO till 7-30) 2017/03/27 17:15:47 Sounds reasonable, but it would be better to make
liaoyuke 2017/03/28 00:16:40 Acknowledged.
+ if (_navigationManager) {
+ _navigationManager->OnNavigationItemsPruned(1U);
+ }
}
- (BOOL)isSameDocumentNavigationBetweenItem:(web::NavigationItem*)firstItem
« no previous file with comments | « no previous file | ios/web/navigation/navigation_manager_impl.mm » ('j') | ios/web/navigation/navigation_manager_impl.mm » ('J')

Powered by Google App Engine
@@ -369,7 +369,7 @@ - (void)clearForwardItems {
if (_previousItemIndex >= forwardItemStartIndex)
_previousItemIndex = -1;
- // Remove the NavigationItems and notify the NavigationManater
+ // Remove the NavigationItems and notify the NavigationManager.
_items.erase(_items.begin() + forwardItemStartIndex, _items.end());
if (_navigationManager) {
This is Rietveld 408576698